@@ -1,31 +1,34 @@
-#' Build articles
+#' Build articles section
 #'
-#' Each R Markdown vignette in `vignettes/` and its subdirectories is
-#' rendered and saved to `articles/`. Vignettes are rendered using a
-#' special document format that reconciles [rmarkdown::html_document()] with
-#' your pkgdown template.
+#' Each R Markdown vignette in `vignettes/` and its subdirectories is rendered
+#' and saved to `articles/`. Vignettes are rendered using a special document
+#' format that reconciles [rmarkdown::html_document()] with your pkgdown
+#' template.
+#'
+#' A vignette with the same name as the package (e.g., `vignettes/pkgdown.Rmd`)
+#' gets special treatment. It is rendered and linked to in the navbar under
+#' "Get started".
 #'
 #' @section External files:
-#' pkgdown differs from base R in its handling of external files. When
-#' building vignettes, R assumes that vignettes are self-contained
-#' (a reasonable assumption when most vignettes were PDFs) and only copies
-#' files explicitly listed in `.install_extras`. pkgdown takes a different
-#' approach based on [rmarkdown::find_external_resources], and it will also
-#' copy any images that you link to. If for some reason the automatic
-#' detection doesn't work, you will need to add a `resource_files` field to
-#' the yaml metadata, .e.g
+#' pkgdown differs from base R in its handling of external files. When building
+#' vignettes, R assumes that vignettes are self-contained (a reasonable
+#' assumption when most vignettes were PDFs) and only copies files explicitly
+#' listed in `.install_extras`. pkgdown takes a different approach based on
+#' [rmarkdown::find_external_resources()], and it will also copy any images that
+#' you link to. If for some reason the automatic detection doesn't work, you
+#' will need to add a `resource_files` field to the yaml metadata, e.g.:
 #'
 #' ```
 #' ---
 #' title: My Document
 #' resource_files:
-#'  - data/mydata.csv
-#'  - images/figure.png
+#'   - data/mydata.csv
+#'   - images/figure.png
 #' ---
 #' ```
 #'
-#' Note that you can not use the `fig.path` to change the output directory
-#' of generated figures as the default is a strong assumption of rmarkdown.
+#' Note that you can not use the `fig.path` to change the output directory of
+#' generated figures as its default value is a strong assumption of rmarkdown.
 #'
 #' @section YAML config:
 #' To tweak the index page, you need a section called `articles`,
@@ -33,7 +36,7 @@
 #' `contents`, and optional `description`.
 #'
 #' For example, this imaginary file describes some of the structure of
-#' the \href{http://rmarkdown.rstudio.com/articles.html}{R markdown articles}:
+#' the [R markdown articles](http://rmarkdown.rstudio.com/articles.html):
 #'
 #' ```
 #' articles:
@@ -51,7 +54,7 @@
 #' common prefix or suffix, you can use `starts_with("prefix")` and
 #' `ends_with("suffix")` to select them all. If you don't care about
 #' position within the string, use `contains("word")`. For more complex
-#' naming schemes you can use an aribrary regular expression with
+#' naming schemes you can use an arbitrary regular expression with
 #' `matches("regexp")`.
 #'
 #' pkgdown will check that all vignettes are included in the index
@@ -59,18 +62,21 @@
 #'
 #' @section YAML header:
 #' By default, pkgdown builds all articles with [rmarkdown::html_document()]
-#' using setting the `template` parameter to a custom built template that
-#' matches the site template. You can override this with a `pkgdown` field
-#' in your yaml metadata:
+#' using setting the `template` parameter. This overrides any custom settings
+#' you have in your YAML metadata, ensuring that all articles are rendered
+#' in the same way (and receive the default site template).
+#'
+#' If you need to override the output format, or set any options, you'll need
+#' to add a `pkgdown` field to your yaml metadata:
 #'
 #' ```
 #' pkgdown:
 #'   as_is: true
 #' ```
 #'
-#' This will tell pkgdown to use the `output_format` that you have specified.
-#' This format must accept `template`, `theme`, and `self_contained` in
-#' order to work with pkgdown.
+#' This will tell pkgdown to use the `output_format` (and options) that you
+#' have specified. This format must accept `template`, `theme`, and
+#' `self_contained` in order to work with pkgdown.
 #'
 #' If the output format produces a PDF, you'll also need to specify the
 #' `extension` field:
@@ -80,14 +86,27 @@
 #'   as_is: true
 #'   extension: pdf
 #' ```
-#' @inheritSection build_reference Figures
-#' @section Supressing vignettes:
 #'
+#' @inheritSection build_reference Figures
+#'
+#' @section Suppressing vignettes:
 #' If you want articles that are not vignettes, either put them in
-#' subdirectories or list in `.Rbuildignore`. An articles link
-#' will be automatically added to the default navbar if the vignettes
-#' directory is present: if you do not want this, you will need to
-#' customise the navbar. See [build_site()] details.
+#' subdirectories or list in `.Rbuildignore`. An articles link will be
+#' automatically added to the default navbar if the vignettes directory is
+#' present: if you do not want this, you will need to customise the navbar. See
+#' [build_site()] details.
+#'
+#' Vignette files prefixed with an underscore (e.g., `_index.Rmd`) are ignored
+#' to enable rendering of [bookdown](https://bookdown.org/yihui/bookdown/)
+#' sites.
+#'
+#' @section Tables of contents:
+#' You can control the TOC depth via the YAML configuration file:
+#'
+#' ```
+#' toc:
+#'   depth: 2
+#' ```
 #'
 #' @inheritParams as_pkgdown
 #' @param quiet Set to `FALSE` to display output of knitr and
@@ -173,7 +192,7 @@ build_article <- function(name,
     format <- NULL
 
     if (identical(ext, "html")) {
-      template <- rmarkdown_template(pkg, depth = depth, data = data)
+      template <- rmarkdown_template(pkg, "article", depth = depth, data = data)
 
       options <- list(
         template = template$path,
@@ -184,7 +203,13 @@ build_article <- function(name,
       options <- list()
     }
   } else {
-    format <- build_rmarkdown_format(pkg, depth = depth, data = data, toc = TRUE)
+    format <- build_rmarkdown_format(
+      pkg = pkg,
+      name = "article",
+      depth = depth,
+      data = data,
+      toc = TRUE
+    )
     options <- NULL
   }
 
@@ -199,15 +224,16 @@ build_article <- function(name,
 }
 
 build_rmarkdown_format <- function(pkg,
+                                   name,
                                    depth = 1L,
                                    data = list(),
                                    toc = TRUE) {
 
-  template <- rmarkdown_template(pkg, depth = depth, data = data)
+  template <- rmarkdown_template(pkg, name, depth = depth, data = data)
 
   out <- rmarkdown::html_document(
     toc = toc,
-    toc_depth = 2,
+    toc_depth = pkg$meta$toc$depth %||% 2,
     self_contained = FALSE,
     theme = NULL,
     template = template$path
@@ -223,9 +249,9 @@ build_rmarkdown_format <- function(pkg,
 # inst/template/article-vignette.html
 # Output is a path + environment; when the environment is garbage collected
 # the path will be deleted
-rmarkdown_template <- function(pkg, data, depth) {
+rmarkdown_template <- function(pkg, name, data, depth) {
   path <- tempfile(fileext = ".html")
-  render_page(pkg, "article", data, path, depth = depth, quiet = TRUE)
+  render_page(pkg, name, data, path, depth = depth, quiet = TRUE)
 
   # Remove template file when format object is GC'd
   e <- env()
