@@ -1,26 +1,24 @@
 #' Build news section
 #'
-#' Your `NEWS.md` is parsed in to sections based on your use of
-#' headings. Each minor version (i.e. the combination of first and second
-#' components) gets on one page, with all patch versions (i.e. the third
-#' component) on a single page. News items for development versions (by
-#' convention those versions with a fourth component) are displayed on an
-#' an "unreleased" page.
+#' Your `NEWS.md` is parsed in to sections based on your use of headings.
 #'
-#' The `NEWS.md` file should be formatted somewhat like this:
+#' The `NEWS.md` file should be formatted with level one headings (`#`)
+#' containing the package name and version number, level two headings (`##`)
+#' with topic headings and lists of news bullets. Commonly used level two
+#' headings include 'Major changes', 'Bug fixes', or 'Minor changes'.
 #'
 #' ```
 #' # pkgdown 0.1.0.9000
 #'
 #' ## Major changes
 #'
-#'  - Fresh approach based on the staticdocs package. Site configuration now based on YAML files.
-#'
-#' ...
+#' - Fresh approach based on the staticdocs package. Site configuration now based
+#'   on YAML files.
 #' ```
 #'
-#' Commonly used subsection headers include 'Major changes', 'Bug fixes', 'Minor
-#' changes'.
+#' If the package is available on CRAN, release dates will be added to versions
+#' in level-one headings, and "Unreleased" will be added versions that are not on
+#' CRAN.
 #'
 #' Issues and contributors mentioned in news items are automatically linked to
 #' github if a `URL` entry linking to github.com is provided in the package
@@ -32,8 +30,6 @@
 #'   - Lots of bug fixes (@hadley, #100)
 #' ```
 #'
-#' If the package is available on CRAN, release dates will be added for listed versions.
-#'
 #' @section YAML config:
 #'
 #' To automatically link to release announcements, include a `releases`
@@ -55,6 +51,7 @@
 #' news:
 #' - one_page: false
 #' ```
+#' @seealso [Tidyverse style for News](http://style.tidyverse.org/news.html)
 #'
 #' @inheritParams build_articles
 #' @export
@@ -212,7 +209,11 @@ is_dev <- function(version) {
 }
 
 pkg_timeline <- function(package) {
-  url <- paste0("http://crandb.r-pkg.org/", package, "/all")
+  if (!has_internet()) {
+    return(NULL)
+  }
+
+  url <- paste0("https://crandb.r-pkg.org/", package, "/all")
 
   resp <- httr::GET(url)
   if (httr::http_error(resp)) {
@@ -229,13 +230,6 @@ pkg_timeline <- function(package) {
   )
 }
 
-rel_date_html <- function(date) {
-  if (is.na(date))
-    return("<small> Unreleased</small>")
-
-  paste0("<small> ", date, "</small>")
-}
-
 tweak_news_heading <- function(x, versions, timeline) {
   x %>%
     xml2::xml_find_all(".//h1") %>%
