@@ -1,14 +1,13 @@
 #' Build reference section
 #'
-#' By default, pkgdown will generate an index that simply lists all
-#' the functions in alphabetical order. To override this, provide a
-#' `reference` section in your `_pkgdown.yml` as described
-#' below.
+#' By default, pkgdown will generate an index that lists all functions in
+#' alphabetical order. To override this, provide a `reference` section in your
+#' `_pkgdown.yml` as described below.
 #'
 #' @section YAML config:
-#' To tweak the index page, you need a section called `reference`
-#' which provides a list of sections containing, a `title`, list of
-#' `contents`, and optional `description`.
+#' To tweak the index page, add a section called `reference` to `_pkgdown.yml`
+#' which provides a list of sections containing, a `title`, list of `contents`,
+#' and an optional `description`.
 #'
 #' For example, the following code breaks up the functions in pkgdown
 #' into two groups:
@@ -25,25 +24,41 @@
 #'   - render_page
 #' ```
 #'
-#' Note that `contents` can contain either a list of function names,
-#' or if the functions in a section share a common prefix or suffix, you
-#' can use `starts_with("prefix")` and `ends_with("suffix")` to
-#' select them all. For more complex naming schemes you can use an aribrary
-#' regular expression with `matches("regexp")`. You can also use a leading
-#' `-` to exclude matches from a section. By default, these functions that
-#' match multiple topics will exclude topics with keyword "internal". To
-#' include, use (e.g.) `starts_with("build_", internal = TRUE)`.
+#' Note that `contents` can contain either a list of function names, or if the
+#' functions in a section share a common prefix or suffix, you can use
+#' `starts_with("prefix")` and `ends_with("suffix")` to select them all. For
+#' more complex naming schemes you can use an arbitrary regular expression with
+#' `matches("regexp")`. You can also use a leading `-` to exclude matches from a
+#' section. By default, these functions that match multiple topics will exclude
+#' topics with the Rd keyword "internal". To include these, use
+#' `starts_with("build_", internal = TRUE)`.
 #'
-#' Alternatively, you can selected topics that contain specified concepts with
-#' `has_concept("blah")`. Concepts are not currently well-supported by
-#' roxygen2, but may be useful if you write Rd files by hand.
+#' You can alo select topics that contain specified Rd concepts with
+#' `has_concept("blah")`.
+#'
+#' You can provide long descriptions for groups of functions using the YAML `>`
+#' notation:
+#'
+#' ```
+#' desc: >
+#'   This is a very long and overly flowery description of a
+#'   single simple function.
+#' ```
+#'
+#' If you have functions with odd names (e.g. that start with a plus symbol
+#' `+`), you can include them by double-escaping. This YAML entry adds the
+#' `+.gg` function to the ggplot2 documentation:
+#'
+#' ```
+#' - "`+.gg`"
+#' ```
 #'
 #' pkgdown will check that all non-internal topics are included on
 #' this page, and will generate a warning if you have missed any.
 #'
 #' @section Figures:
 #'
-#' You can control the default rendering of figues by specifying the `figures`
+#' You can control the default rendering of figures by specifying the `figures`
 #' field in `_pkgdown.yml`. The default settings are equivalent to:
 #'
 #' ```
@@ -59,55 +74,27 @@
 #' ```
 #'
 #' @section Icons:
-#' You can optionally supply an icon for each help topic. To do so, you'll
-#' need a top-level `icons` directory. This should contain {.png} files
-#' that are either 30x30 (for regular display) or 60x60 (if you want
-#' retina display). Icons are matched to topics by aliases.
+#' You can optionally supply an icon for each help topic. To do so, you'll need
+#' a top-level `icons` directory. This should contain {.png} files that are
+#' either 30x30 (for regular display) or 60x60 (if you want retina display).
+#' Icons are matched to topics by aliases.
 #'
 #' @inheritParams build_articles
 #' @param lazy If `TRUE`, only rebuild pages where the `.Rd`
 #'   is more recent than the `.html`. This makes it much easier to
-#'   rapidly protoype. It is set to `FALSE` by [build_site()].
+#'   rapidly prototype. It is set to `FALSE` by [build_site()].
 #' @param document If `TRUE`, will run [devtools::document()] before
 #'   updating the site.
 #' @param run_dont_run Run examples that are surrounded in \\dontrun?
 #' @param examples Run examples?
-#' @param mathjax Use mathjax to render math symbols?
 #' @param seed Seed used to initialize so that random examples are
 #'   reproducible.
 #' @export
-#' @examples
-#' # This example illustrates some important output types
-#' # The following output should be wrapped over multiple lines
-#' a <- 1:100
-#' a
-#'
-#' cat("This some text!\n")
-#' message("This is a message!")
-#' warning("This is a warning!")
-#'
-#' # This is a multi-line block
-#' {
-#'   1 + 2
-#'   2 + 2
-#' }
-#'
-#' \dontrun{
-#' stop("This is an error!", call. = FALSE)
-#' }
-#'
-#' \donttest{
-#' # This code won't generally be run by CRAN. But it
-#' # will be run by pkgdown
-#' b <- 10
-#' a + b
-#' }
 build_reference <- function(pkg = ".",
                             lazy = TRUE,
                             document = FALSE,
                             examples = TRUE,
                             run_dont_run = FALSE,
-                            mathjax = TRUE,
                             seed = 1014,
                             override = list(),
                             preview = NA
@@ -115,7 +102,7 @@ build_reference <- function(pkg = ".",
   pkg <- section_init(pkg, depth = 1L, override = override)
 
   rule("Building function reference")
-  if (document && (pkg$package != "pkgdown")) {
+  if (document && (pkg$package != "pkgdown") && is_installed("devtools")) {
     devtools::document(pkg$src_path)
   }
 
@@ -132,7 +119,9 @@ build_reference <- function(pkg = ".",
     # Re-loading pkgdown while it's running causes weird behaviour with
     # the context cache
     if (!(pkg$package %in% c("pkgdown", "rprojroot"))) {
-      devtools::load_all(pkg$src_path)
+      pkgload::load_all(pkg$src_path, export_all = FALSE, helpers = FALSE)
+    } else {
+      library(pkg$package, character.only = TRUE)
     }
 
     old_dir <- setwd(path(pkg$dst_path, "reference"))
@@ -150,8 +139,7 @@ build_reference <- function(pkg = ".",
     pkg = pkg,
     lazy = lazy,
     examples = examples,
-    run_dont_run = run_dont_run,
-    mathjax = mathjax
+    run_dont_run = run_dont_run
   )
 
   preview_site(pkg, "reference", preview = preview)
@@ -182,8 +170,7 @@ build_reference_topic <- function(topic,
                                   pkg,
                                   lazy = TRUE,
                                   examples = TRUE,
-                                  run_dont_run = FALSE,
-                                  mathjax = TRUE
+                                  run_dont_run = FALSE
                                   ) {
 
   in_path <- path(pkg$src_path, "man", topic$file_in)
@@ -199,8 +186,7 @@ build_reference_topic <- function(topic,
     topic,
     pkg,
     examples = examples,
-    run_dont_run = run_dont_run,
-    mathjax = mathjax
+    run_dont_run = run_dont_run
   )
   render_page(
     pkg, "reference-topic",
@@ -216,8 +202,7 @@ build_reference_topic <- function(topic,
 data_reference_topic <- function(topic,
                                  pkg,
                                  examples = TRUE,
-                                 run_dont_run = FALSE,
-                                 mathjax = TRUE
+                                 run_dont_run = FALSE
                                  ) {
   tag_names <- purrr::map_chr(topic$rd, ~ class(.)[[1]])
   tags <- split(topic$rd, tag_names)
@@ -235,8 +220,8 @@ data_reference_topic <- function(topic,
   out$filename <- topic$file_in
 
   # Multiple top-level converted to string
+  out$author <- purrr::map_chr(tags$tag_author %||% list(), flatten_para)
   out$aliases <- purrr::map_chr(tags$tag_alias %||% list(), flatten_text)
-  out$author <- purrr::map_chr(tags$tag_author %||% list(), flatten_text)
   out$keywords <- purrr::map_chr(tags$tag_keyword %||% list(), flatten_text)
 
   # Sections that contain arbitrary text and need cross-referencing
