@@ -99,46 +99,52 @@ as_html.tag_subsection <- function(x, ...) {
 # Equations ------------------------------------------------------------------
 
 #' @export
-as_html.tag_eqn <- function(x, ..., mathjax = TRUE) {
-  stopifnot(length(x) <= 2)
-  if (isTRUE(mathjax)){
-    latex_rep <- x[[1]]
-    paste0("\\(", flatten_text(latex_rep, ...), "\\)")
-  }else{
-    ascii_rep <- x[[length(x)]]
-    paste0("<code class = 'eq'>", flatten_text(ascii_rep, ...), "</code>")
+as_html.tag_eqn <- function(x, ...) {
+  if (length(x) > 2) {
+    stop_bad_tag("eqn")
   }
+
+  latex_rep <- x[[1]]
+  paste0("\\(", flatten_text(latex_rep, ...), "\\)")
 }
 
 #' @export
-as_html.tag_deqn <- function(x, ..., mathjax = TRUE) {
-  stopifnot(length(x) <= 2)
-  if (isTRUE(mathjax)) {
-    latex_rep <- x[[1]]
-    paste0("$$", flatten_text(latex_rep, ...), "$$")
-  }else{
-    ascii_rep <- x[[length(x)]]
-    paste0("<pre class = 'eq'>", flatten_text(ascii_rep, ...), "</pre>")
+as_html.tag_deqn <- function(x, ...) {
+  if (length(x) > 2) {
+    stop_bad_tag("deqn")
   }
+  latex_rep <- x[[1]]
+  paste0("$$", flatten_text(latex_rep, ...), "$$")
 }
 
 # Links ----------------------------------------------------------------------
 #' @export
 as_html.tag_url <- function(x, ...) {
-  stopifnot(length(x) == 1)
+  if (length(x) != 1) {
+    if (length(x) == 0) {
+      msg <- "Check for empty \\url{} tags."
+    } else {
+      msg <- "This may be caused by a \\url tag that spans a line break."
+    }
+    stop_bad_tag("url", msg)
+  }
 
   text <- flatten_text(x[[1]])
   a(text, href = text)
 }
 #' @export
 as_html.tag_href <- function(x, ...) {
-  stopifnot(length(x) == 2)
+  if (length(x) != 2) {
+    stop_bad_tag("href")
+  }
 
   a(flatten_text(x[[2]]), href = flatten_text(x[[1]]))
 }
 #' @export
 as_html.tag_email <- function(x, ...) {
-  stopifnot(length(x) %in% c(1L, 2L))
+  if (!length(x) %in% c(1L, 2L)) {
+    stop_bad_tag("email")
+  }
   paste0("<a href='mailto:", x[[1]], "'>", x[[length(x)]], "</a>")
 }
 
@@ -185,7 +191,9 @@ as_html.tag_link <- function(x, ...) {
 
 #' @export
 as_html.tag_linkS4class <- function(x, ...) {
-  stopifnot(length(x) == 1)
+  if (length(x) != 1) {
+    stop_bad_tag("linkS4class")
+  }
 
   text <- flatten_text(x[[1]])
   href <- href_topic_local(paste0(text, "-class"))
@@ -257,15 +265,22 @@ as_html.tag_tabular <- function(x, ...) {
   align <- unname(c("r" = "right", "l" = "left", "c" = "center")[align_abbr])
 
   contents <- x[[2]]
-  row_sep <- purrr::map_lgl(contents, inherits, "tag_cr")
-  col_sep <- purrr::map_lgl(contents, inherits, "tag_tab")
+  class <- purrr::map_chr(contents, ~ class(.x)[[1]])
+  cell_contents <- purrr::map_chr(contents, flatten_text, ...)
 
+  row_sep <- class == "tag_cr"
+  contents[row_sep] <- list("")
+  col_sep <- class == "tag_tab"
   sep <- col_sep | row_sep
-  cell_grp <- cumsum(sep)
-  cells <- split(contents[!sep], cell_grp[!sep])
 
-  cell_contents <- vapply(cells, flatten_text, ...,
-    FUN.VALUE = character(1), USE.NAMES = FALSE)
+  # Look for separators that have no text in front of them
+  no_text <- c(TRUE, class[-length(class)] != "TEXT")
+  keep <- !(sep & !no_text)
+  # data.frame(class, sep, no_text, keep)
+
+  cell_grp <- cumsum(keep)
+  cells <- unname(split(contents[keep], cell_grp[keep]))
+  cell_contents <- purrr::map_chr(cells, flatten_text, ...)
   cell_contents <- paste0("<td>", str_trim(cell_contents), "</td>")
   cell_contents <- matrix(cell_contents, ncol = length(align), byrow = TRUE)
 
@@ -525,8 +540,9 @@ parse_opts <- function(string) {
   names(args) <- args
   arg_env <- child_env(baseenv(), !!!args)
 
+
   args <- strsplit(string, ",")[[1]]
-  exprs <- parse_exprs(args)
+  exprs <- purrr::map(args, parse_expr)
 
   env <- child_env(arg_env)
   purrr::walk(exprs, eval_bare, env = env)
@@ -534,3 +550,14 @@ parse_opts <- function(string) {
   as.list(env)
 }
 
+stop_bad_tag <- function(tag, msg = NULL) {
+  fxn <- context_get("rdname")
+
+  msg <- paste0(
+    "Function `", fxn,
+    "` contains a bad Rd tag of type `", tag,
+    "`. ", msg
+  )
+
+  stop(msg, call. = FALSE)
+}
