@@ -27,6 +27,14 @@ test_that("can parse function/methods", {
   expect_equal(usage$type, "s4")
   expect_equal(usage$name, "f")
   expect_equal(usage$signature, c("bar", "baz"))
+
+  usage <- parse_usage("pkg::func()")[[1]]
+  expect_equal(usage$type, "fun")
+  expect_equal(usage$name, "func")
+
+  usage <- parse_usage("pkg:::func()")[[1]]
+  expect_equal(usage$type, "fun")
+  expect_equal(usage$name, "func")
 })
 
 test_that("can parse replacement functions", {
@@ -82,7 +90,6 @@ test_that("can parse dots", {
   expect_equal(usage$name, "f")
 })
 
-
 # short_name --------------------------------------------------------------
 
 test_that("infix functions left as", {
